Static assets, such as images and pre-built JS and CSS, are collected here from
``govuk_template``, ``govuk-elements-sass`` and ``govuk_frontend_toolkit``.

If libsass or the [scss] extra was installed, a base CSS file (``stylesheets/base.css``) is built from defaults.
Use the ``buildscss`` management command to compile SCSS files.
